=======
History
=======

0.3.0 (2019-12-20)
------------------

Added
~~~~~
* Option to store output in ``new.bib``
* Intro and examples to ``README.rst``

0.2.1 (2019-12-20)
------------------

Added
~~~~~
* ``get_minimal_bibs`` function.
* tests for ``tex_to_tags`` and ``get_minimal_bibs``.

Fixed
~~~~~
* Documentation builds.
* Deploy from Travis.

Removed
~~~~~~~
* Support for ``Python 3.5`` (no f-string support)

0.1.0 (2019-12-16)
------------------

* First release on PyPI.
